@@ -12,10 +12,11 @@ from os import environ as environ
 # TODO: figure out how to avoid import when no graphical environment exists
 from agstoolbox.at_trayindicator import run_tray_indicator
 from agstoolbox.core.cmdline.cmdline import cmdline
+from agstoolbox import __title__
 
 
 def main():
-    """"
+    """
     agstoolbox main routine
     When you use `python -m agstoolbox`, the main routine is called.
     If you use `pip install agstoolbox`, typing agstoolbox will also call this routine.
@@ -25,7 +26,7 @@ def main():
     """
     environ["LIBOVERLAY_SCROLLBAR"] = "0"
 
-    ap_args = cmdline(False)
+    ap_args = cmdline(False, __title__)
     run_tray_indicator(ap_args)
 
 
